@@ -34,9 +34,10 @@
 #' @return xts
 #' @export
 crypto2xts <- function(df, frequency = NULL) {
-  if (as.character(match.call()[[1]]) == "crypto2xts") {
-    warning("DEPRECATED: Please use crypto_xts() instead of crypto2xts().", call. = TRUE, immediate. = TRUE)
-  }
+  ifelse(as.character(match.call()[[1]]) == "crypto2xts",
+    warning("DEPRECATED: Please use crypto_xts() instead of crypto2xts().", call. = TRUE, immediate. = TRUE),
+    print(" ")
+  )
   slug <- ""
   symbol <- ""
   name <- ""
